@@ -25,8 +25,10 @@
 #ifndef __MODULES_H__
 #define __MODULES_H__
 
+extern PangoIncludedModule _pango_included_lang_modules[];
 extern PangoIncludedModule _pango_included_x_modules[];
 extern PangoIncludedModule _pango_included_fc_modules[];
 extern PangoIncludedModule _pango_included_win32_modules[];
+extern PangoIncludedModule _pango_included_atsui_modules[];
 
 #endif /* __MODULES_H__ */
