@@ -68,6 +68,7 @@ GType         pango_cairo_font_map_get_type          (void) G_GNUC_CONST;
 PangoFontMap *pango_cairo_font_map_new               (void);
 PangoFontMap *pango_cairo_font_map_new_for_font_type (cairo_font_type_t fonttype);
 PangoFontMap *pango_cairo_font_map_get_default       (void);
+void          pango_cairo_font_map_set_default       (PangoCairoFontMap *fontmap);
 cairo_font_type_t pango_cairo_font_map_get_font_type (PangoCairoFontMap *fontmap);
 
 void          pango_cairo_font_map_set_resolution (PangoCairoFontMap *fontmap,
@@ -104,6 +105,7 @@ PangoCairoShapeRendererFunc pango_cairo_context_get_shape_renderer (PangoContext
 
 /* Convenience
  */
+PangoContext *pango_cairo_create_context (cairo_t   *cr);
 PangoLayout *pango_cairo_create_layout (cairo_t     *cr);
 void         pango_cairo_update_layout (cairo_t     *cr,
 					PangoLayout *layout);
